@@ -6,7 +6,7 @@ use warnings;
 use Carp;
 
 require Exporter;
-use AutoLoader;
+use SelfLoader;
 
 our @ISA = qw(Exporter);
 
@@ -55,7 +55,7 @@ our @EXPORT = qw(
 	MCRYPT_FAILED
 );
 
-our $VERSION = '1.0.3';
+our $VERSION = '1.0.4';
 
 sub AUTOLOAD {
     # This AUTOLOAD is used to 'autoload' constants from the constant()
@@ -88,16 +88,20 @@ XSLoader::load('Crypt::Libmcrypt', $VERSION);
 # Autoload methods go after =cut, and are processed by the autosplit program.
 
 1;
-__END__
+__DATA__
 # Below is stub documentation for your module. You'd better edit it!
 
+=pod
+
+=encoding utf8
+
 =head1 NAME
 
 Crypt::Libmcrypt
 
 =head1 VERSION
 
-version 1.0.3
+version 1.0.4
 
 =head1 SYNOPSIS
 
